@@ -1035,6 +1035,10 @@ PyAPI_FUNC(void) _PyPyGC_AddMemoryPressure(Signed arg0);
 extern void _PyPy_Free(void *arg0);
 #define _PyPy_Malloc _PyPyPy_Malloc
 extern void * _PyPy_Malloc(Signed arg0);
+#define _PySet_Next _PyPySet_Next
+PyAPI_FUNC(int) _PySet_Next(PyObject *arg0, Signed *arg1, PyObject **arg2);
+#define _PySet_NextEntry _PyPySet_NextEntry
+PyAPI_FUNC(int) _PySet_NextEntry(PyObject *arg0, Signed *arg1, PyObject **arg2, Signed *arg3);
 #define _PyString_Eq _PyPyString_Eq
 PyAPI_FUNC(int) _PyString_Eq(PyObject *arg0, PyObject *arg1);
 #define _PyString_Join _PyPyString_Join
